@@ -1,5 +1,6 @@
 import json
 import time
+import os
 from io import open
 
 from django.conf import settings
@@ -11,17 +12,16 @@ from .exceptions import (
     WebpackLoaderTimeoutError,
     WebpackBundleLookupError
 )
-from .config import load_config
 
 
 class WebpackLoader(object):
     _assets = {}
 
-    def __init__(self, name='DEFAULT'):
+    def __init__(self, name, config):
         self.name = name
-        self.config = load_config(self.name)
+        self.config = config
 
-    def _load_assets(self):
+    def load_assets(self):
         try:
             with open(self.config['STATS_FILE'], encoding="utf-8") as f:
                 return json.load(f)
@@ -34,25 +34,37 @@ class WebpackLoader(object):
     def get_assets(self):
         if self.config['CACHE']:
             if self.name not in self._assets:
-                self._assets[self.name] = self._load_assets()
+                self._assets[self.name] = self.load_assets()
             return self._assets[self.name]
-        return self._load_assets()
+        return self.load_assets()
 
     def filter_chunks(self, chunks):
+        filtered_chunks = []
+
         for chunk in chunks:
-            ignore = any(regex.match(chunk['name'])
+            ignore = any(regex.match(chunk)
                          for regex in self.config['ignores'])
             if not ignore:
-                chunk['url'] = self.get_chunk_url(chunk)
-                yield chunk
+                filtered_chunks.append(chunk)
 
-    def get_chunk_url(self, chunk):
-        public_path = chunk.get('publicPath')
+        return filtered_chunks
+
+    def map_chunk_files_to_url(self, chunks):
+        assets = self.get_assets()
+        files = assets['assets']
+
+        for chunk in chunks:
+            url = self.get_chunk_url(files[chunk])
+            yield { 'name': chunk, 'url': url }
+
+    def get_chunk_url(self, chunk_file):
+        public_path = chunk_file.get('publicPath')
         if public_path:
             return public_path
 
-        relpath = '{0}{1}'.format(
-            self.config['BUNDLE_DIR_NAME'], chunk['name']
+        # Use os.path.normpath for Windows paths
+        relpath = os.path.normpath(
+            os.path.join(self.config['BUNDLE_DIR_NAME'], chunk_file['name'])
         )
         return staticfiles_storage.url(relpath)
 
@@ -65,7 +77,7 @@ class WebpackLoader(object):
             timeout = self.config['TIMEOUT'] or 0
             timed_out = False
             start = time.time()
-            while assets['status'] == 'compiling' and not timed_out:
+            while assets['status'] == 'compile' and not timed_out:
                 time.sleep(self.config['POLL_INTERVAL'])
                 if timeout and (time.time() - timeout > start):
                     timed_out = True
@@ -81,7 +93,15 @@ class WebpackLoader(object):
             chunks = assets['chunks'].get(bundle_name, None)
             if chunks is None:
                 raise WebpackBundleLookupError('Cannot resolve bundle {0}.'.format(bundle_name))
-            return self.filter_chunks(chunks)
+
+            filtered_chunks = self.filter_chunks(chunks)
+
+            for chunk in filtered_chunks:
+                asset = assets['assets'][chunk]
+                if asset is None:
+                    raise WebpackBundleLookupError('Cannot resolve asset {0}.'.format(chunk))
+
+            return self.map_chunk_files_to_url(filtered_chunks)
 
         elif assets.get('status') == 'error':
             if 'file' not in assets:
